/**
SerIO Light Sensor Example Application
Written by Ryan Owens
SparkFun Electronics

Sketch Description:
This sketch illustrates how to interface between the SerIO platform from SparkFun Electronics
and a photocell. The sketch loads two images on top of one another and adjusts the transparency
of the top image according to the reading of the photocell.

Circuit Description:
10K resistor from pin A5 to GND.
Photocell from pin A5 to 3.3V.
 */


import processing.serial.*;

Serial myPort;        // Create object from Serial class
String response="";  //Create a string to hold the responses from the SerIO board.

PImage a, b;          //Create two image objects for the images.
int transparency=0;   //Create a variable to hold the value retrieved from the photo cell. Also used to set the transparency of the top image.

void setup() 
{ 
  b = loadImage("Light_Bulb.jpg");  // Load an image into the program 
  a = loadImage("Dark_Bulb.jpg");   // Load an image into the program 
  size(a.width/4, a.height/4);      // Set the size of the window
  
  //Create and open a COM port to communicate with the SerIO
  String portName = Serial.list()[1];  //Select a com port. This may have to be changed on your computer; this is the default com port on a Windows PC.
  myPort = new Serial(this, portName, 57600);  //Open a connection on the selected COM port with a baud rate of 57600.
  
  //Wait for the SerIO board to issue the 'Ready' command.
  while(match(getResponse(), "Ready") == null);
}

void draw() {
  background(255);  // Set the background color of the window.
  
  //Send SerIO a command to Read Analog Pin 5. This will retrieve the value of the photocell.
  myPort.write("a,5\r");
  
  //Wait for the SerIO to send a response; capture the string into 'response.'
  response=getResponse();
  //println(response);  //Uncomment this line to see what the SerIO response was.
  
  //Find out if this the response contains a value
  //A valid response from the SerIO will be in the form "Pin: X\tValue: XXX\r"
  //See the SerIO User Guide for more information.
  String[] search = match(response, "Value");    
  //If we found the word 'Value' in the response, parse out the integer value.
  if(search != null){
    String[] list = split(response, ": ");  //Split the response into 3 sections. The actual value will be in the last secion
    transparency=int(parseFloat(list[2]));  //Parse the value out of the response string. This is the value of the photocell.
    //println(list[2]);  //Uncomment this line to have the sketch print the value which has been parsed out of the response string.
    transparency=int(map(float(transparency), 200, 780, 0, 255)); //Convert serial value into an integer in the range 0-255
  }
  
  //Draw the images
  image(a, 0, 0, a.width/4, a.height/4);  //Put the first image onto the screen. 
  tint(255, transparency);                //Set the transparency for the next image. Use the transparency value obtained from the photocell.
  image(b, 0,0,b.width/4,b.height/4);     //Put the second image on top of the first image.
  noTint();                               //Remove the tint settings on anything else.
}

//The getResponse function is used to get a response string from the SerIO platform.
//Function assumes that a global serial port has been created and opened and given the name myPort.
String getResponse()
{
  String serial_string="";  //This string will hold the characters received from the SerIO.
  int message_complete=0;  //Used as a flag to indicate the end of the response string.
  char val = 0;        // Data received from the serial port

  //Read characters from the Serial Port until the carriage return character is received.
  while(message_complete==0)
  {
    if(myPort.available() > 0)  //If a character is at the serial port, read it!
    {
      val=(char)myPort.read();  //Copy the character from the Serial Port.
      serial_string = serial_string + str(val);  //Add the newest character to the end of the string.
      if(val == '\r')  //If we receive a carriage return character, set the message_complete flag so we can exit the function
      {
        message_complete=1;
      }
    }
  }
  
  return serial_string;  //Send the response string back to the caller.
}  
